#!ruby
# -*- mode: ruby; coding: utf-8 -*-
# Last updated: <2021/08/17 20:43:42 +0900>
#
# Ogg sample play example with vaudiorb

require "dxruby"
require_relative "VAudio"

title = "Ogg sample play example with vaudiorb"

Window.caption = title
fnt = Font.new(24)

pan = 0.0
volume = 100.0

VAudio.enableFileType("OGG", true)
VAudio.enableFileType("MP3", false)
VAudio.enableFileType("MIDI", false)
VAudio.enableFileType("FLAC", false)

VAudio.init(Window.hWnd)  # init vAudio

s = VAudio.loadSample("jingle.ogg")  # load ogg

totaltime = s.getTotalTime  # get total time

s.setVolume(volume)  # set volume
s.setPan(pan)  # set pan

s.setRepeat(false)  # loop disable
# s.setLoopPoints(totaltime / 2, -1)  # set loop points

effects = VAudio::EFFECTS.keys
effect_idx = 0

Window.loop do
  break if Input.keyPush?(K_ESCAPE)

  # pan (Left: -1.0, Center: 0.0, Right: 1.0)
  # Left, Right key
  if Input.x != 0
    pan += Input.x * 0.02
    pan = -1.0 if pan < -1.0
    pan = 1.0 if pan > 1.0
    s.setPan(pan)
  end

  # volume (0.0 - 100.0)
  # Up, Down key
  if Input.y != 0
    volume -= Input.y
    volume = 0.0 if volume < 0.0
    volume = 100.0 if volume > 100.0
    s.setVolume(volume)
  end

  # effect type
  if Input.keyPush?(K_E)
    effect_idx = (effect_idx + 1) % effects.length
    efname = effects[effect_idx]
    s.setEffect(VAudio::EFFECTS[efname])
  end

  # reset pan and volume and effect
  if Input.keyPush?(K_R)
    pan = 0.0
    volume = 100.0
    effect_idx = 0
    s.setPan(pan)
    s.setVolume(volume)
    s.setEffect(VAudio::EFFECTS["NONE"])
  end

  s.play if Input.keyPush?(K_Z)  # play
  s.stop if Input.keyPush?(K_X)  # pause
  s.resume if Input.keyPush?(K_C)  # resume

  s.fadeout(1500) if Input.keyPush?(K_V)  # fadeout
  s.resumeFadein(1500) if Input.keyPush?(K_B)  # resume fadein
  s.fadein(1500) if Input.keyPush?(K_N)  # fadein

  # draw text
  y = 2
  dy = 26
  [
    title,
    "",
    "Z: Play",
    "X: Stop (Pause)",
    "C: Resume",
    "V: Fadeout",
    "B: Resume Fadein",
    "N: Fadein",
    "R: Reset pan, volume",
    "E: Effects",
    "Left Right: pan",
    "Up Down: volume",
  ].each do |m|
    Window.draw_font(8, y, m, fnt)
    y += dy
  end

  y += dy * 0.5
  Window.draw_font(8, y, "pan: #{pan}", fnt)
  y += dy
  Window.draw_font(8, y, "volume: #{volume}", fnt)
  y += dy
  Window.draw_font(8, y, "effect: #{effects[effect_idx]}", fnt)
  y += dy

  ct = s.getCurrentTime
  tt = s.getTotalTime
  playing = ((s.isPlaying) ? "Playing" : "Stopped")
  tm = sprintf("%08d / %08d (msec) : %s", ct, tt, playing)
  Window.draw_font(8, y, tm, fnt)
end

s.free
VAudio.free
